︠9ed98528-2a05-4258-bfc8-e8259488ec51i︠
%html
<h2>Reed-Frost epidemic model</h2>

<p>In this stochastic model, there are three classes of individuals: Susceptible, Infected, and Recovered (or Removed).
At each time step, susceptible individuals are infected by one of the infected individuals with probability p.
Infected individuals recover in one time step.</p>

<p>This demo plots the number of infected (red) and susceptible (blue) individuals over time.
A histogram of final epidemic sizes (total number infected) is also shown.
By default, the code plots the results of 10 stochastic runs.
You can set the number of runs, p, and the initial number of susceptible and infected individuals.</p>

︡9fb1bebb-53ea-4e96-a8df-e046b8a3a069︡{"html": "<h2>Reed-Frost epidemic model</h2>\r\n\r\n<p>In this stochastic model, there are three classes of individuals: Susceptible, Infected, and Recovered (or Removed).\r\nAt each time step, susceptible individuals are infected by one of the infected individuals with probability p.\r\nInfected individuals recover in one time step.</p>\r\n\r\n<p>This demo plots the number of infected (red) and susceptible (blue) individuals over time.\r\nA histogram of final epidemic sizes (total number infected) is also shown.\r\nBy default, the code plots the results of 10 stochastic runs.\r\nYou can set the number of runs, p, and the initial number of susceptible and infected individuals.</p>"}︡
︠7ac23f57-0a77-4c42-8ecc-c939b1e04750s︠
#Reed-Frost epidemic model
from scipy import stats

@interact
def reed_frost(S0 = input_box(100, label = 'S[0]: '), I0 = input_box(1, label = 'I[0]: '), p = input_box(0.05, label = 'p: '), n = input_box(10, label = 'trials: ')):
    q = 1-p
    iplot = line([0,0])
    splot = line([0,0])
    finalsizebinsize = 1
    while ((I0+S0)/finalsizebinsize>100):
        finalsizebinsize = finalsizebinsize*10
    while ((I0+S0)/finalsizebinsize>30):
        finalsizebinsize = finalsizebinsize*2
    finalsize = [0 for i in xrange(int((I0+S0)/finalsizebinsize)+1)]
    for i in xrange(n):
        I = I0
        S = S0
        Ilist = [I]
        Slist = [S]
        t = 1
        while (I>0):
            if (S>0):
                I = stats.binom.rvs(S,1-(q^I))
            else:
                I = 0
            S = S-I
            Ilist.append(I)
            Slist.append(S)
        bin = int(sum(Ilist)/finalsizebinsize)
        finalsize[bin] = finalsize[bin]+1
        iplot = iplot + list_plot(Ilist,plotjoined=True,rgbcolor=(1,0,0))
        splot = splot + list_plot(Slist,plotjoined=True,rgbcolor=(0,0,1))
    show(iplot+splot, axes_labels=['time', 'individuals'])
    fseq = IndexedSequence(finalsize,range(int((I0+S0)/finalsizebinsize)+1))
    show(fseq.plot_histogram(), axes_labels=['final size x %d' % finalsizebinsize, 'frequency'])
︡0cf3db40-b10e-436c-9e28-866aaf78184b︡{"interact":{"style":"None","flicker":false,"layout":[[["S0",12,null]],[["I0",12,null]],[["p",12,null]],[["n",12,null]],[["",12,null]]],"id":"7641f87a-42ca-4f4d-add6-3711065aff1a","controls":[{"control_type":"input-box","default":100,"label":"S[0]: ","nrows":1,"width":null,"readonly":false,"submit_button":null,"var":"S0","type":null},{"control_type":"input-box","default":1,"label":"I[0]: ","nrows":1,"width":null,"readonly":false,"submit_button":null,"var":"I0","type":null},{"control_type":"input-box","default":"0.0500000000000000","label":"p: ","nrows":1,"width":null,"readonly":false,"submit_button":null,"var":"p","type":null},{"control_type":"input-box","default":10,"label":"trials: ","nrows":1,"width":null,"readonly":false,"submit_button":null,"var":"n","type":null}]}}︡
︠10a1003a-406b-4b55-9b1d-1c85610077bd︠









